summaryrefslogtreecommitdiffstats
path: root/src/modules/mediaplayer
diff options
context:
space:
mode:
authorDarrell Anderson <humanreadable@yahoo.com>2014-02-16 14:59:03 -0600
committerDarrell Anderson <humanreadable@yahoo.com>2014-02-16 14:59:03 -0600
commit6aea5c55b658aebf50c6acd9d9ab29382d8a5256 (patch)
treeecf48ad9226f34c7858ea9e16290fa9caf460afb /src/modules/mediaplayer
parentd31f7a29a4eb62e233e02cb36bebd7038b99de7e (diff)
downloadkvirc-6aea5c55b658aebf50c6acd9d9ab29382d8a5256.tar.gz
kvirc-6aea5c55b658aebf50c6acd9d9ab29382d8a5256.zip
Fix unintended renaming
Diffstat (limited to 'src/modules/mediaplayer')
-rw-r--r--src/modules/mediaplayer/mp_winampinterface.cpp8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/modules/mediaplayer/mp_winampinterface.cpp b/src/modules/mediaplayer/mp_winampinterface.cpp
index ef7e4c7..493e097 100644
--- a/src/modules/mediaplayer/mp_winampinterface.cpp
+++ b/src/modules/mediaplayer/mp_winampinterface.cpp
@@ -73,10 +73,10 @@
// ** 11 Enabled. zero if disabled, nonzero if enabled.
// ** 12 Autoload. zero if disabled, nonzero if enabled.
-#define IPC_SETETQDATA 128
+#define IPC_SETEQDATA 128
// ** SendMessage(hwnd_winamp,WM_WA_IPC,pos,IPC_GETEQDATA);
// ** SendMessage(hwnd_winamp,WM_WA_IPC,value,IPC_SETETQDATA);
// ** IPC_SETETQDATA sets the value of the last position retrieved
// ** by IPC_GETEQDATA. This is pretty lame, and we should provide
// ** an extended version that lets you do a MAKELPARAM(pos,value).
// ** someday...
@@ -502,7 +502,7 @@ bool KviWinampInterface::setEqData(int &iPos, int &iVal)
if(hWinamp)
{
SendMessage(hWinamp,WM_USER,iPos,IPC_GETEQDATA);
- SendMessage(hWinamp,WM_USER,iVal,IPC_SETETQDATA);
+ SendMessage(hWinamp,WM_USER,iVal,IPC_SETEQDATA);
return true;
}
return false;
@@ -73,10 +73,10 @@
// ** SendMessage(hwnd_winamp,WM_WA_IPC,pos,IPC_GETEQDATA);
-// ** SendMessage(hwnd_winamp,WM_WA_IPC,value,IPC_SETETQDATA);
-// ** IPC_SETETQDATA sets the value of the last position retrieved
+// ** SendMessage(hwnd_winamp,WM_WA_IPC,value,IPC_SETEQDATA);
+// ** IPC_SETEQDATA sets the value of the last position retrieved
// ** by IPC_GETEQDATA. This is pretty lame, and we should provide
// ** an extended version that lets you do a MAKELPARAM(pos,value).